@@ -881,6 +881,14 @@
         <source>Original RadioTraffic.com Traffic Reconciliation (DEPRECATED)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Disc Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disc Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1644,6 +1652,14 @@ vozík</translation>
         <source>Unable to read CD.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to create temporary directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CD-TEXT</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDEditAudio</name>
