@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Cart
 //
-//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2022 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -65,7 +65,7 @@ class RDCart
   QString schedCodes() const;
   void setSchedCodes(const QString &sched_codes) const;
   QStringList schedCodesList() const;
-  void setSchedCodesList(const QStringList &codes) const;
+  void setSchedCodesList(QStringList codes) const;
   void addSchedCode(const QString &code) const;
   void removeSchedCode(const QString &code) const;
   void updateSchedCodes(const QString &add_codes,
@@ -173,6 +173,8 @@ class RDCart
   static unsigned readXml(std::vector<RDWaveData> *data,const QString &xml);
   static QString uniqueCartTitle(unsigned cartnum=0);
   static bool titleIsUnique(unsigned except_cartnum,const QString &str);
+  static QString ensureTitleIsUnique(unsigned except_cartnum,
+				     const QString &str);
   
  private:
   static QVariant GetXmlValue(const QString &tag,const QString &line);
@@ -181,7 +183,6 @@ class RDCart
   RDCut::Validity ValidateCut(RDSqlQuery *q,bool enforce_length,
 			      unsigned length,bool *time_ok) const;
   QString VerifyTitle(const QString &title) const;
-
   void SetRow(const QString &param,const QString &value) const;
   void SetRow(const QString &param,unsigned value) const;
   void SetRow(const QString &param,const QDateTime &value) const;
