@@ -2,9 +2,7 @@
 //
 // The cart slot widget.
 //
-//   (C) Copyright 2012 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcartslot.h,v 1.8.2.10 2013/12/30 17:07:08 cvs Exp $
+//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,41 +21,21 @@
 #ifndef RDCARTSLOT_H
 #define RDCARTSLOT_H
 
-#include <vector>
-
-#include <qwidget.h>
-#include <qdatetime.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qsignalmapper.h>
-
-#include <rdpushbutton.h>
-
 #include <rdcart_dialog.h>
-#include <rdcart.h>
-#include <rduser.h>
-#include <rdlog_line.h>
-#include <rdplay_deck.h>
-#include <rdpanel_button.h>
-#include <rdbutton_dialog.h>
-#include <rdbutton_panel.h>
-#include <rdripc.h>
-#include <rdcombobox.h>
-#include <rdsvc.h>
-#include <rdslotbox.h>
-#include <rdslotdialog.h>
-#include <rdslotoptions.h>
 #include <rdcueeditdialog.h>
 #include <rdlistsvcs.h>
+#include <rdslotbox.h>
+#include <rdslotdialog.h>
+#include <rdwidget.h>
 
-class RDCartSlot : public QWidget
+class RDCartSlot : public RDWidget
 {
  Q_OBJECT
  public:
   RDCartSlot(int slotnum,RDRipc *ripc,RDCae *cae,RDStation *station,
 	     RDConfig *config,RDListSvcs *svcs_dialog,RDSlotDialog *slot_dialog,
 	     RDCartDialog *cart_dialog,RDCueEditDialog *cue_dialog,
-	     const QString &caption,QWidget *parent=0);
+	     const QString &caption,RDAirPlayConf *conf,QWidget *parent=0);
   ~RDCartSlot();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -128,6 +106,7 @@ class RDCartSlot : public QWidget
   int slot_breakaway_length;
   bool slot_timescaling_active;
   bool slot_temp_cart;
+  RDAirPlayConf *slot_airplay_conf;
 };
 
 #endif  // RDCARTSLOT_H
