@@ -2,7 +2,7 @@
 //
 // Abstract an RDLibrary Configuration.
 //
-//   (C) Copyright 2002-2003,2016-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2022 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,14 +18,20 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <QPixmap>
+
 #include <rddb.h>
 #include <rdconf.h>
 #include <rdlibrary_conf.h>
 #include <rdescape_string.h>
 
 //
-// Global Classes
+// Logos
 //
+#include "../icons/cd-text-55x47.xpm"
+#include "../icons/cddb-60x25.xpm"
+#include "../icons/musicbrainz-159x25.xpm"
+
 RDLibraryConf::RDLibraryConf(const QString &station)
 {
   RDSqlQuery *q;
@@ -414,7 +420,7 @@ QString RDLibraryConf::cdServerTypeText(RDLibraryConf::CdServerType type)
     break;
 
   case RDLibraryConf::CddbType:
-    ret="FreeDB";
+    ret="CDDB";
     break;
 
   case RDLibraryConf::MusicBrainzType:
@@ -428,6 +434,30 @@ QString RDLibraryConf::cdServerTypeText(RDLibraryConf::CdServerType type)
 }
 
 
+QPixmap RDLibraryConf::cdServerLogo(CdServerType type)
+{
+  QPixmap ret;
+
+  switch(type) {
+  case RDLibraryConf::DummyType:
+    ret=QPixmap(cd_text_55x47_xpm);
+    break;
+
+  case RDLibraryConf::CddbType:
+    ret=QPixmap(cddb_60x25_xpm);
+    break;
+
+  case RDLibraryConf::MusicBrainzType:
+    ret=QPixmap(musicbrainz_159x25_xpm);
+    break;
+
+  case RDLibraryConf::LastType:
+    break;
+  }
+  return ret;
+}
+
+
 void RDLibraryConf::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
