@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Netcatch Recording.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -616,6 +616,18 @@ void RDRecording::setUrlPassword(QString passwd) const
 }
 
 
+bool RDRecording::urlUseIdFile() const
+{
+  return RDBool(GetStringValue("URL_PASSWORD"));
+}
+
+
+void RDRecording::setUrlUseIdFile(bool state) const
+{
+  SetRow("URL_USE_ID_FILE",RDYesNo(state));
+}
+
+
 bool RDRecording::enableMetadata() const
 {
   return GetBoolValue("ENABLE_METADATA");
