@@ -92,6 +92,8 @@ class RDSoundPanel : public RDWidget
 		      const QString &);
   void changeUser();
   void tickClock();
+  void panelUp();
+  void panelDown();
 
  signals:
   void tick();
@@ -114,6 +116,9 @@ class RDSoundPanel : public RDWidget
   void onairFlagChangedData(bool state);
   void scanPanelData();
 
+ protected:
+  void wheelEvent(QWheelEvent *e);
+
  private:
   void PlayButton(RDAirPlayConf::PanelType type,int panel,int row,int col,
 		RDLogLine::StartSource src,bool hookmode,int mport=-1,
