@@ -3,7 +3,7 @@
 // Functions for interfacing with web components using the
 // Common Gateway Interface (CGI) Standard 
 //
-//   (C) Copyright 1996-2007 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 1996-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,14 +30,15 @@
 #include <qdatetime.h>
 #include <qstringlist.h>
 
-#include <rdescape_string.h>
-#include <rduser.h>
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdwebresult.h>
-
-#include <rdweb.h>
+#include "rdconf.h"
+#include "rddatetime.h"
+#include "rddb.h"
+#include "rdescape_string.h"
+#include "rdtempdirectory.h"
+#include "rduser.h"
+#include "rdwebresult.h"
 
+#include "rdweb.h"
 
 /* RDReadPost(char *cBuffer,int dSize) */
 
@@ -554,7 +555,6 @@ void RDCgiError(const char *str,int resp_code)
 }
 
 
-#ifndef WIN32
 extern void RDXMLResult(const char *str,int resp_code,
 			RDAudioConvert::ErrorCode err)
 {
@@ -568,7 +568,6 @@ extern void RDXMLResult(const char *str,int resp_code,
 
   exit(0);
 }
-#endif  // WIN32
 
 
 /*
@@ -783,7 +782,7 @@ bool RDParsePost(std::map<QString,QString> *vars)
   //
   // Initialize Temp Directory Path
   //
-  tempdir = RDTempDir() + "/rivendellXXXXXX";
+  tempdir=RDTempDirectory::basePath()+"/rivendellXXXXXX";
 
   //
   // Get message part separator
@@ -822,10 +821,10 @@ bool RDParsePost(std::map<QString,QString> *vars)
       if(QString(data).stripWhiteSpace().isEmpty()) {
 	if(!headers["content-disposition"].isNull()) {
 	  QStringList fields;
-	  fields=fields.split(";",headers["content-disposition"]);
+	  fields=headers["content-disposition"].split(";");
 	  if(fields.size()>0) {
 	    if(fields[0].lower().stripWhiteSpace()=="form-data") {
-	      for(unsigned i=1;i<fields.size();i++) {
+	      for(int i=1;i<fields.size();i++) {
 		QStringList pairs;
 		pairs=pairs.split("=",fields[i]);
 		if(pairs[0].lower().stripWhiteSpace()=="name") {
@@ -851,7 +850,7 @@ bool RDParsePost(std::map<QString,QString> *vars)
       }
       else {
 	QStringList hdr;
-	hdr=hdr.split(":",QString(data).stripWhiteSpace());
+	hdr=QString(data).trimmed().split(":");
 	headers[hdr[0].lower()]=hdr[1];
       }
     }
@@ -934,7 +933,21 @@ QString RDXmlField(const QString &tag,const QDateTime &value,
     str=" "+attrs;
   }
   if(value.isValid()) {
-    return QString("<")+tag+str+">"+RDXmlDateTime(value)+"</"+tag+">\n";
+    return QString("<")+tag+str+">"+RDWriteXmlDateTime(value)+"</"+tag+">\n";
+  }
+  return RDXmlField(tag);
+}
+
+
+QString RDXmlField(const QString &tag,const QDate &value,const QString &attrs)
+{
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  if(value.isValid()&&(!value.isNull())) {
+    return QString("<")+tag+str+">"+RDWriteXmlDate(value)+"</"+tag+">\n";
   }
   return RDXmlField(tag);
 }
@@ -948,7 +961,7 @@ QString RDXmlField(const QString &tag,const QTime &value,const QString &attrs)
     str=" "+attrs;
   }
   if(value.isValid()&&(!value.isNull())) {
-    return QString("<")+tag+str+">"+RDXmlTime(value)+"</"+tag+">\n";
+    return QString("<")+tag+str+">"+RDWriteXmlTime(value)+"</"+tag+">\n";
   }
   return RDXmlField(tag);
 }
@@ -960,47 +973,6 @@ QString RDXmlField(const QString &tag)
 }
 
 
-QString RDXmlDate(const QDate &date)
-{
-  return date.toString("yyyy-MM-dd")+RDXmlTimeZoneSuffix();
-}
-
-
-QString RDXmlTime(const QTime &time)
-{
-  return time.toString("hh:mm:ss")+RDXmlTimeZoneSuffix();
-}
-
-
-QString RDXmlDateTime(const QDateTime &datetime)
-{
-  return datetime.toString("yyyy-MM-dd")+"T"+datetime.toString("hh:mm:ss")+
-    RDXmlTimeZoneSuffix();
-}
-
-
-QString RDXmlTimeZoneSuffix()
-{
-  QString ret;
-  int tz=RDTimeZoneOffset();
-
-  if(tz==0) {
-    ret+="Z";
-  }
-  else {
-    if(tz<0) {
-      ret+="+";
-    }
-    if(tz>0) {
-      ret+="-";
-    }
-    ret+=QTime(0,0,0).addSecs(tz).toString("hh:mm");
-  }
-
-  return ret;
-}
-
-
 QString RDXmlEscape(const QString &str)
 {
   /*
@@ -1031,6 +1003,127 @@ QString RDXmlUnescape(const QString &str)
 }
 
 
+QString RDJsonPadding(int padding)
+{
+  QString ret="";
+
+  for(int i=0;i<padding;i++) {
+    ret+=" ";
+  }
+  return ret;
+}
+
+
+QString RDJsonNullField(const QString &name,int padding,bool final)
+{
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  return RDJsonPadding(padding)+"\""+name+"\": null"+comma+"\r\n";
+}
+
+
+QString RDJsonField(const QString &name,bool value,int padding,bool final)
+{
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  if(value) {
+    return RDJsonPadding(padding)+"\""+name+"\": true"+comma+"\r\n";
+  }
+  return RDJsonPadding(padding)+"\""+name+"\": false"+comma+"\r\n";
+}
+
+
+QString RDJsonField(const QString &name,int value,int padding,bool final)
+{
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  return RDJsonPadding(padding)+"\""+name+"\": "+QString().sprintf("%d",value)+
+    comma+"\r\n";
+}
+
+
+QString RDJsonField(const QString &name,unsigned value,int padding,bool final)
+{
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  return RDJsonPadding(padding)+"\""+name+"\": "+QString().sprintf("%u",value)+
+    comma+"\r\n";
+}
+
+
+QString RDJsonField(const QString &name,const QString &value,int padding,
+		    bool final)
+{
+  QString ret;
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  for(int i=0;i<value.length();i++) {
+    QChar c=value.at(i);
+    switch(c.category()) {
+    case QChar::Other_Control:
+      ret+=QString().sprintf("\\u%04X",c.unicode());
+      break;
+
+    default:
+      switch(c.unicode()) {
+      case 0x22:   // Quote
+	ret+="\\\"";
+	break;
+
+      case 0x5C:   // Backslash
+	ret+="\\\\";
+	break;
+
+      default:
+	ret+=c;
+	break;
+      }
+      break;
+    }
+  }
+
+  return RDJsonPadding(padding)+"\""+name+"\": \""+ret+"\""+comma+"\r\n";
+}
+
+
+QString RDJsonField(const QString &name,const QDateTime &value,int padding,
+		    bool final)
+{
+  QString comma=",";
+
+  if(final) {
+    comma="";
+  }
+
+  if(!value.isValid()) {
+    return RDJsonNullField(name,padding,final);
+  }
+  return RDJsonPadding(padding)+"\""+name+"\": \""+
+    RDWriteXmlDateTime(value)+"\""+
+    comma+"\r\n";
+}
+
+
 QString RDUrlEscape(const QString &str)
 {
   /*
@@ -1064,8 +1157,8 @@ QString RDUrlUnescape(const QString &str)
    */
   QString ret="";
 
-  for(unsigned i=0;i<str.length();i++) {
-    if((str.at(i)=="%")&&(i<str.length()-2)) {
+  for(int i=0;i<str.length();i++) {
+    if((str.at(i).ascii()=='%')&&(i<str.length()-2)) {
       ret+=QString().sprintf("%c",str.mid(i+1,2).toInt(NULL,16));
       i+=2;
     }
@@ -1076,261 +1169,3 @@ QString RDUrlUnescape(const QString &str)
 
   return ret;
 }
-
-
-QString RDWebDateTime(const QDateTime &datetime)
-{
-  //
-  // Generate an RFC 822/1123 compliant date/time string
-  //
-  if(!datetime.isValid()) {
-    return QString();
-  }
-  return RDLocalToUtc(datetime).toString("ddd, dd MMM yyyy hh:mm:ss")+" GMT";
-}
-
-
-QDateTime RDGetWebDateTime(const QString &str,bool *ok)
-{
-  QDateTime ret;
-  QStringList list;
-  QStringList f0;
-  QStringList f1;
-  QStringList f2;
-  int day;
-  int month;
-  int year;
-  QTime time;
-  bool lok=false;
-
-  if(ok!=NULL) {
-    *ok=false;
-  }
-
-  f0=f0.split(" ",str.stripWhiteSpace());
-  switch(f0.size()) {
-  case 1:   // XML xs:dateTime Style
-    f1=f1.split("T",f0[0]);
-    if(f1.size()<=2) {
-      f2=QStringList::split("-",f1[0]);
-      if(f2.size()==3) {
-       year=f2[0].toInt(&lok);
-       if(lok&&(year>0)) {
-         month=f2[1].toInt(&lok);
-         if(lok&&(month>=1)&&(month<=12)) {
-           day=f2[2].toInt(&lok);
-           if(lok&&(day>=1)&&(day<=31)) {
-             if(f1.size()==2) {
-               time=RDGetWebTime(f1[1],&lok);
-               if(lok) {
-                 ret=QDateTime(QDate(year,month,day),time);
-                 if(ok!=NULL) {
-                   *ok=true;
-                 }
-               }
-             }
-           }
-         }
-       }
-      }
-    }
-    break;
-
-  case 4:   // RFC 850 Style
-    f1=f1.split("-",f0[1]);
-    if(f1.size()==3) {
-      month=RDGetWebMonth(f1[1],&lok);
-      if(ok) {
-	time=RDGetWebTime(f0[2]+" "+f0[3],&lok);
-	if(lok) {
-	  year=f1[2].toInt(&lok);
-	  if(lok&&(year>0)) {
-	    day=f1[0].toInt(&lok);
-	    if(lok&&(day>0)&&(day<=31)) {
-	      ret=QDateTime(QDate(year+2000,month,day),time);
-	      if(ok!=NULL) {
-		*ok=true;
-	      }
-	    }
-	  }
-	}
-      }
-    }
-    break;
-
-  case 5:   // ANSI C asctime() Style
-    month=RDGetWebMonth(f0[1],&lok);
-    if(lok) {
-      time=RDGetWebTime(f0[3]+" GMT",&lok);
-      if(lok) {
-	year=f0[4].toInt(&lok);
-	if(lok&&(year>0)) {
-	  day=f0[2].toInt(&lok);
-	  if(lok&&(day>0)&&(day<=31)) {
-	    ret=QDateTime(QDate(year,month,day),time);
-	    if(ok!=NULL) {
-	      *ok=true;
-	    }
-	  }
-	}
-      }
-    }
-    break;
-
-  case 6:   // RFC 822/1123 Style
-    month=RDGetWebMonth(f0[2],&lok);
-    if(lok) {
-      time=RDGetWebTime(f0[4]+" "+f0[5],&lok);
-      if(lok) {
-	year=f0[3].toInt(&lok);
-	if(lok&&(year>0)) {
-	  day=f0[1].toInt(&lok);
-	  if(lok&&(day>0)&&(day<=31)) {
-	    ret=QDateTime(QDate(year,month,day),time);
-	    if(ok!=NULL) {
-	      *ok=true;
-	    }
-	  }
-	}
-      }
-    }
-    break;
-  }
-  return ret;
-}
-
-
-QTime RDGetWebTime(const QString &str,bool *ok)
-{
-  QTime ret;
-  QStringList f0;
-  QStringList f1;
-  QStringList f2;
-  bool lok=false;
-  int tz=0;
-  QTime time;
-  QTime tztime;
-
-  if(ok!=NULL) {
-    *ok=false;
-  }
-  f0=f0.split(" ",str.stripWhiteSpace());
-  switch(f0.size()) {
-  case 1:   // XML xs:time Style
-    if(f0[0].right(1).lower()=="z") {  // GMT
-      tz=RDTimeZoneOffset();
-      f0[0]=f0[0].left(f0[0].length()-1);
-      f2=f2.split(":",f0[0]);
-    }
-    else {
-      f1=QStringList::split("+",f0[0]);
-      if(f1.size()==2) {   // GMT+
-       f2=QStringList::split(":",f1[1]);
-       if(f2.size()==2) {
-         tztime=QTime(f2[0].toInt(),f2[1].toInt(),0);
-         if(tztime.isValid()) {
-           tz=RDTimeZoneOffset()+QTime(0,0,0).secsTo(tztime);
-         }
-       }
-      }
-      else {
-       f1=QStringList::split("-",f0[0]);
-       if(f1.size()==2) {   // GMT-
-         f2=QStringList::split(":",f1[1]);
-         if(f2.size()==2) {
-           tztime=QTime(f2[0].toInt(),f2[1].toInt(),0);
-           if(tztime.isValid()) {
-             tz=RDTimeZoneOffset()-QTime(0,0,0).secsTo(tztime);
-           }
-         }
-       }
-      }
-      f2=f2.split(":",f1[0]);
-    }
-    if(f2.size()==3) {
-      time=QTime(f2[0].toInt(),f2[1].toInt(),f2[2].toInt());
-      if(time.isValid()) {
-       ret=time.addSecs(tz);
-       if(ok!=NULL) {
-         *ok=true;
-       }
-      }
-    }
-    break;
-
-  case 2:   // RFC Style
-    if(f0[1].lower()=="gmt") {
-      f0=f0.split(":",f0[0]);
-      if(f0.size()==3) {
-	int hour=f0[0].toInt(&lok);
-	if(lok) {
-	  int min=f0[1].toInt(&lok);
-	  if(lok) {
-	    int sec=f0[2].toInt(&lok);
-	    if(lok) {
-	      if((hour>=0)&&(hour<=23)&&(min>=0)&&(min<=59)&&(sec>=0)&&
-		 (sec<=60)) {
-		ret=RDUtcToLocal(QTime(f0[0].toInt(),f0[1].toInt(),
-				       f0[2].toInt()));
-		if(ok!=NULL) {
-		  *ok=true;
-		}
-	      }
-	    }
-	  }
-	}
-      }
-    }
-    break;
-  }
-
-  return ret;
-}
-
-
-int RDGetWebMonth(const QString &str,bool *ok)
-{
-  int ret=0;
-
-  if(str.lower()=="jan") {
-    ret=1;
-  }
-  if(str.lower()=="feb") {
-    ret=2;
-  }
-  if(str.lower()=="mar") {
-    ret=3;
-  }
-  if(str.lower()=="apr") {
-    ret=4;
-  }
-  if(str.lower()=="may") {
-    ret=5;
-  }
-  if(str.lower()=="jun") {
-    ret=6;
-  }
-  if(str.lower()=="jul") {
-    ret=7;
-  }
-  if(str.lower()=="aug") {
-    ret=8;
-  }
-  if(str.lower()=="sep") {
-    ret=9;
-  }
-  if(str.lower()=="oct") {
-    ret=10;
-  }
-  if(str.lower()=="nov") {
-    ret=11;
-  }
-  if(str.lower()=="dec") {
-    ret=12;
-  }
-  if(ok!=NULL) {
-    *ok=ret!=0;
-  }
-
-  return ret;
-}
