@@ -2,7 +2,7 @@
 //
 // Add a Rivendell Group
 //
-//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,25 +21,28 @@
 #include <qdialog.h>
 #include <qstring.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
+
 #include <rddb.h>
+#include <rdescape_string.h>
 
 #include <edit_group.h>
 #include <add_group.h>
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
-#include <rdescape_string.h>
 
 AddGroup::AddGroup(QString *group,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   group_group=group;
 
   //
@@ -50,15 +53,7 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  setCaption(tr("Add Group"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont user_font=QFont("Helvetica",12,QFont::Normal);
-  user_font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("Add Group"));
 
   //
   // Text Validator
@@ -73,9 +68,10 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   group_name_edit->setMaxLength(10);
   group_name_edit->setValidator(validator);
   QLabel *label=new QLabel(group_name_edit,tr("&New Group Name:"),this);
+  label->setFont(labelFont());
   label->setGeometry(10,11,130,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Enable Users Checkbox
@@ -84,9 +80,9 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   group_users_box->setGeometry(40,40,15,15);
   group_users_box->setChecked(true);
   label=new QLabel(group_users_box,tr("Enable Group for All Users"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(60,38,sizeHint().width()-60,19);
-  label->setFont(user_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Enable Services Checkbox
@@ -95,9 +91,9 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   group_svcs_box->setGeometry(40,61,15,15);
   group_svcs_box->setChecked(true);
   label=new QLabel(group_svcs_box,tr("Enable Group for All Services"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(60,58,sizeHint().width()-60,19);
-  label->setFont(user_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   //  Ok Button
@@ -105,7 +101,7 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -115,7 +111,7 @@ AddGroup::AddGroup(QString *group,QWidget *parent)
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
@@ -150,8 +146,8 @@ void AddGroup::okData()
     return;
   }
 
-  sql=QString().sprintf("insert into GROUPS set NAME=\"%s\"",
-			(const char *)RDEscapeString(group_name_edit->text()));
+  sql=QString("insert into GROUPS set ")+
+    "NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
 
   q=new RDSqlQuery(sql);
   if(!q->isActive()) {
@@ -169,10 +165,9 @@ void AddGroup::okData()
     sql="select LOGIN_NAME from USERS";
     q=new RDSqlQuery(sql);
     while(q->next()) {
-      sql=QString().sprintf("insert into USER_PERMS set USER_NAME=\"%s\",\
-                             GROUP_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)RDEscapeString(group_name_edit->text()));
+      sql=QString("insert into USER_PERMS set ")+
+	"USER_NAME=\""+RDEscapeString(q->value(0).toString())+"\","+
+	"GROUP_NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -186,10 +181,9 @@ void AddGroup::okData()
     sql="select NAME from SERVICES";
     q=new RDSqlQuery(sql);
     while(q->next()) {
-      sql=QString().sprintf("insert into AUDIO_PERMS set SERVICE_NAME=\"%s\",\
-                             GROUP_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)RDEscapeString(group_name_edit->text()));
+      sql=QString("insert into AUDIO_PERMS set ")+
+	"SERVICE_NAME=\""+RDEscapeString(q->value(0).toString())+"\","+
+	"GROUP_NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -198,16 +192,16 @@ void AddGroup::okData()
 
   EditGroup *group=new EditGroup(group_name_edit->text(),this);
   if(group->exec()<0) {
-    sql=QString().sprintf("delete from USER_PERMS where GROUP_NAME=\"%s\"",
-			  (const char *)RDEscapeString(group_name_edit->text()));
+    sql=QString("delete from USER_PERMS where ")+
+      "GROUP_NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
     q=new RDSqlQuery(sql);
     delete q;
-    sql=QString().sprintf("delete from AUDIO_PERMS where GROUP_NAME=\"%s\"",
-			  (const char *)RDEscapeString(group_name_edit->text()));
+    sql=QString("delete from AUDIO_PERMS where ")+
+      "GROUP_NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
     q=new RDSqlQuery(sql);
     delete q;
-    sql=QString().sprintf("delete from GROUPS where NAME=\"%s\"",
-			  (const char *)RDEscapeString(group_name_edit->text()));
+    sql=QString("delete from GROUPS where ")+
+      "NAME=\""+RDEscapeString(group_name_edit->text())+"\"";
     q=new RDSqlQuery(sql);
     delete q;
     delete group;
