@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Workstation
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_station.h,v 1.11 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,22 +21,21 @@
 #ifndef ADD_STATION_H
 #define ADD_STATION_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qpixmap.h>
 #include <qcombobox.h>
 #include <qsqldatabase.h>
 #include <qlineedit.h>
 
+#include <rddialog.h>
 #include <rdstation.h>
 
-
-class AddStation : public QDialog
+class AddStation : public RDDialog
 {
   Q_OBJECT
   public:
-   AddStation(QString *stationname,QWidget *parent=0,const char *name=0);
+   AddStation(QString *stationname,QWidget *parent=0);
    ~AddStation();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
