@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Matrix
 //
-//   (C) Copyright 2002-2012 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_matrix.h,v 1.17.6.2 2012/12/10 15:40:14 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,22 +21,21 @@
 #ifndef EDIT_MATRIX_H
 #define EDIT_MATRIX_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <rduser.h>
+#include <rddialog.h>
 #include <rdmatrix.h>
+#include <rduser.h>
 
-class EditMatrix : public QDialog
+class EditMatrix : public RDDialog
 {
  Q_OBJECT
  public:
-  EditMatrix(RDMatrix *matrix,QWidget *parent=0,const char *name=0);
+  EditMatrix(RDMatrix *matrix,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
@@ -54,6 +51,7 @@ class EditMatrix : public QDialog
   void gpisButtonData();
   void gposButtonData();
   void livewireButtonData();
+  void livewireGpioButtonData();
   void vguestRelaysButtonData();
   void vguestDisplaysButtonData();
   void sasResourcesButtonData();
@@ -121,6 +119,7 @@ class EditMatrix : public QDialog
   QPushButton *edit_gpis_button;
   QPushButton *edit_gpos_button;
   QPushButton *edit_livewire_button;
+  QPushButton *edit_livewire_gpio_button;
   QPushButton *edit_vguestrelays_button;
   QPushButton *edit_vguestdisplays_button;
   QPushButton *edit_sasresources_button;
