@@ -2,7 +2,7 @@
 //
 // List Rivendell Replicator Carts
 //
-//   (C) Copyright 2002-2008,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,50 +18,28 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <math.h>
-
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qbuttongroup.h>
-#include <rddb.h>
-
 #include <rdcart.h>
-#include <rdtextfile.h>
+#include <rddb.h>
 #include <rdescape_string.h>
 #include <rdreplicator.h>
+#include <rdtextfile.h>
 
-#include <list_replicator_carts.h>
-#include <edit_replicator.h>
-#include <add_replicator.h>
+#include "add_replicator.h"
+#include "edit_replicator.h"
+#include "list_replicator_carts.h"
 
 #include "../icons/play.xpm"
 #include "../icons/rml5.xpm"
 
 ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setMinimumSize(sizeHint());
 
   //
   // Create Icons
@@ -79,7 +57,7 @@ ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
   //  Repost Button
   //
   list_repost_button=new QPushButton(this);
-  list_repost_button->setFont(font);
+  list_repost_button->setFont(buttonFont());
   list_repost_button->setText(tr("&Repost"));
   connect(list_repost_button,SIGNAL(clicked()),this,SLOT(repostData()));
 
@@ -87,7 +65,7 @@ ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
   //  Repost All Button
   //
   list_repost_all_button=new QPushButton(this);
-  list_repost_all_button->setFont(font);
+  list_repost_all_button->setFont(buttonFont());
   list_repost_all_button->setText(tr("Repost\n&All"));
   connect(list_repost_all_button,SIGNAL(clicked()),this,SLOT(repostAllData()));
 
@@ -96,7 +74,7 @@ ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
   //
   list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -104,7 +82,6 @@ ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
   // Replicator List
   //
   list_view=new RDListView(this);
-  list_view->setFont(list_font);
   list_view->setAllColumnsShowFocus(true);
   list_view->setItemMargin(5);
   list_view->addColumn(" ");
@@ -113,7 +90,7 @@ ListReplicatorCarts::ListReplicatorCarts(QWidget *parent)
   list_view->addColumn(tr("LAST POSTED"));
   list_view->addColumn(tr("POSTED FILENAME"));
   QLabel *list_box_label=new QLabel(list_view,tr("&Active Carts:"),this);
-  list_box_label->setFont(font);
+  list_box_label->setFont(labelFont());
   list_box_label->setGeometry(14,11,85,19);
 }
 
@@ -138,7 +115,7 @@ QSizePolicy ListReplicatorCarts::sizePolicy() const
 int ListReplicatorCarts::exec(const QString &replname)
 {
   list_replicator_name=replname;
-  setCaption(replname+tr(" Replicator Carts"));
+  setWindowTitle("RDAdmin - "+replname+tr(" Replicator Carts"));
   RefreshList();
   list_refresh_timer->start(5000,true);
   return QDialog::exec();
@@ -166,9 +143,9 @@ void ListReplicatorCarts::repostAllData()
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("update REPL_CART_STATE set REPOST=\"Y\" \
-                         where REPLICATOR_NAME=\"%s\"",
-			(const char *)list_replicator_name);
+  sql=QString("update REPL_CART_STATE set ")+
+    "REPOST=\"Y\" where "+
+    "REPLICATOR_NAME=\""+RDEscapeString(list_replicator_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -187,9 +164,11 @@ void ListReplicatorCarts::refreshTimeoutData()
   RDSqlQuery *q;
   RDListViewItem *item;
 
-  sql=QString().sprintf("select ID,ITEM_DATETIME from REPL_CART_STATE \
-                         where REPLICATOR_NAME=\"%s\"",
-			(const char *)RDEscapeString(list_replicator_name));
+  sql=QString("select ")+
+    "ID,"+
+    "ITEM_DATETIME "+
+    "from REPL_CART_STATE where "+
+    "REPLICATOR_NAME=\""+RDEscapeString(list_replicator_name)+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     item=(RDListViewItem *)list_view->firstChild();
@@ -223,15 +202,16 @@ void ListReplicatorCarts::RefreshList()
   RDListViewItem *item;
 
   list_view->clear();
-  sql=QString().sprintf("select REPL_CART_STATE.ID,\
-                         CART.TYPE,REPL_CART_STATE.CART_NUMBER,\
-                         CART.TITLE,\
-                         REPL_CART_STATE.ITEM_DATETIME,\
-                         REPL_CART_STATE.POSTED_FILENAME \
-                         from REPL_CART_STATE left join CART \
-                         on REPL_CART_STATE.CART_NUMBER=CART.NUMBER \
-                         where REPLICATOR_NAME=\"%s\"",
-			(const char *)RDEscapeString(list_replicator_name));
+  sql=QString("select ")+
+    "REPL_CART_STATE.ID,"+               // 00
+    "CART.TYPE,"+                        // 01
+    "REPL_CART_STATE.CART_NUMBER,"+      // 02
+    "CART.TITLE,"+                       // 03
+    "REPL_CART_STATE.ITEM_DATETIME,"+    // 04
+    "REPL_CART_STATE.POSTED_FILENAME "+  // 05
+    "from REPL_CART_STATE left join CART "+
+    "on REPL_CART_STATE.CART_NUMBER=CART.NUMBER where "+
+    "REPLICATOR_NAME=\""+RDEscapeString(list_replicator_name)+"\"";
   q=new RDSqlQuery(sql);
   while (q->next()) {
     item=new RDListViewItem(list_view);
