@@ -2,7 +2,7 @@
 //
 // List Rivendell Users
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -57,10 +57,11 @@ class ListUsers : public RDDialog
   QPushButton *list_close_button;
   QString list_admin_name;
   QPixmap *list_admin_map;
+  QPixmap *list_localuser_map;
+  QPixmap *list_rss_map;
   QPixmap *list_user_map;
 };
 
 
-#endif
-
+#endif  // LIST_USERS_H
 
