@@ -2,9 +2,7 @@
 //
 // Login Widget for RDAdmin.
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: login.h,v 1.4 2007/02/14 21:51:02 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,19 +21,18 @@
 #ifndef LOGIN_H
 #define LOGIN_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qpixmap.h>
 #include <qradiobutton.h>
 
+#include <rddialog.h>
 
-
-class Login : public QDialog
+class Login : public RDDialog
 {
   Q_OBJECT
   public:
-   Login(QString *username,QString *password,QWidget *parent=0,const char *name=0);
+   Login(QString *username,QString *password,QWidget *parent=0);
    ~Login();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
