@@ -513,6 +513,15 @@ Clipboard</source>
         <source>[superfeed]</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to create temporary directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online Feed
+Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
