@@ -2,7 +2,7 @@
 //
 // Add a Rivendell RDCatch Event
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,19 +21,9 @@
 #ifndef ADD_RECORDING_H
 #define ADD_RECORDING_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlineedit.h>
-#include <qdatetimeedit.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qlabel.h>
+#include <rddialog.h>
 
-#include <rdrecording.h>
-#include <rddeck.h>
-
-class AddRecording : public QDialog
+class AddRecording : public RDDialog
 {
   Q_OBJECT
  public:
