@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Netcatch Cart Event
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,22 +21,17 @@
 #ifndef EDIT_CARTEVENT_H
 #define EDIT_CARTEVENT_H
 
-#include <vector>
-
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlineedit.h>
 #include <qdatetimeedit.h>
-#include <qcombobox.h>
+
 #include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qlabel.h>
+#include <qcombobox.h>
 
-#include <rdrecording.h>
 #include <rddeck.h>
+#include <rddialog.h>
 #include <rdcart.h>
+#include <rdrecording.h>
 
-class EditCartEvent : public QDialog
+class EditCartEvent : public RDDialog
 {
  Q_OBJECT
  public:
@@ -52,7 +47,6 @@ class EditCartEvent : public QDialog
   void cancelData();
 
  protected:
-  void paintEvent(QPaintEvent *e);
   void keyPressEvent(QKeyEvent *);
   void closeEvent(QCloseEvent *e);
   
