@@ -2,9 +2,7 @@
 //
 // A container class for a Rivendell netcatch event.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: catch_event.cpp,v 1.17.2.1 2008/11/14 21:30:56 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,11 +18,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <rddatedecode.h>
+
 #include <catch_event.h>
 
-
-CatchEvent::CatchEvent()
+CatchEvent::CatchEvent(RDStation *station,RDConfig *config)
 {
+  catch_station=station;
+  catch_config=config;
   clear();
 }
 
@@ -527,6 +528,18 @@ QString CatchEvent::urlPassword() const
 }
 
 
+bool CatchEvent::enableMetadata() const
+{
+  return catch_enable_metadata;
+}
+
+
+void CatchEvent::setEnableMetadata(bool state)
+{
+  catch_enable_metadata=state;
+}
+
+
 void CatchEvent::setUrlPassword(const QString &passwd)
 {
   catch_url_password=passwd;
@@ -641,6 +654,19 @@ void CatchEvent::setEventdateOffset(int days)
 }
 
 
+void CatchEvent::resolveUrl(int time_offset)
+{
+  QDate date=QDate::currentDate();
+  QTime current_time=QTime::currentTime();
+  if((current_time.msecsTo(QTime(23,59,59))+1000)<time_offset) {
+    date=date.addDays(1);
+  }
+  setResolvedUrl(RDDateTimeDecode(url(),QDateTime(date.addDays(eventdateOffset()),
+						  current_time),catch_station,
+				  catch_config));
+}
+
+
 void CatchEvent::clear()
 {
   catch_id=0;
@@ -683,6 +709,7 @@ void CatchEvent::clear()
   catch_resolved_url="";
   catch_url_username="";
   catch_url_password="";
+  catch_enable_metadata=false;
   catch_temp_length=0;
   catch_final_length=0;
   catch_gpi_start_timer=NULL;
