@@ -302,7 +302,7 @@ Do you still want to delete?</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Cart</source>
-        <translation>Bruk FreeDB-opplysningar på korga</translation>
+        <translation type="obsolete">Bruk FreeDB-opplysningar på korga</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -441,14 +441,6 @@ Rip</source>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rip CD</source>
         <translation type="unfinished">Ripp CD</translation>
@@ -458,6 +450,30 @@ Rip</source>
 Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Metadata</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskGauge</name>
@@ -486,7 +502,7 @@ Track</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Carts</source>
-        <translation>Bruk FreeDB-opplysningar på korgene</translation>
+        <translation type="obsolete">Bruk FreeDB-opplysningar på korgene</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -679,14 +695,6 @@ Disk</source>
         <source>Rip aborted!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -732,6 +740,22 @@ Selection</source>
         <source>Unable to allocate cart in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Metadata</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
