@@ -1,17 +1,19 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>MainWidget</name>
     <message>
         <source>RDLogin - Station:</source>
-        <translation>RDLogin - Stanice:</translation>
+        <translation type="obsolete">RDLogin - Stanice:</translation>
     </message>
     <message>
         <source>rdlogin : </source>
-        <translation>rdlogin :</translation>
+        <translation type="obsolete">rdlogin :</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Nelze spojit</translation>
+        <translation type="obsolete">Nelze spojit</translation>
     </message>
     <message>
         <source>Current User: unknown</source>
@@ -41,7 +43,7 @@ uživatel</translation>
     </message>
     <message>
         <source>Current User:</source>
-        <translation>Nynější uživatel:</translation>
+        <translation type="obsolete">Nynější uživatel:</translation>
     </message>
     <message>
         <source>RDLogin</source>
@@ -55,5 +57,17 @@ uživatel</translation>
         <source>Invalid Username or Password!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current User</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
