@@ -1,18 +1,8 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>MainWidget</name>
-    <message>
-        <source>RDLogin - Station:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>rdlogin : </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Current User: unknown</source>
         <translation type="unfinished"></translation>
@@ -38,16 +28,24 @@ User</source>
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Current User:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLogin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Invalid Password!</source>
+        <source>Invalid Username or Password!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current User</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
