@@ -1,17 +1,19 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>MainWidget</name>
     <message>
         <source>RDLogin - Station:</source>
-        <translation>RDLogin - Estação:</translation>
+        <translation type="obsolete">RDLogin - Estação:</translation>
     </message>
     <message>
         <source>rdlogin : </source>
-        <translation>rdlogin : </translation>
+        <translation type="obsolete">rdlogin : </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Não foi possível conectar</translation>
+        <translation type="obsolete">Não foi possível conectar</translation>
     </message>
     <message>
         <source>Current User: unknown</source>
@@ -42,7 +44,7 @@ Padrão</translation>
     </message>
     <message>
         <source>Current User:</source>
-        <translation>Usuário Atual:</translation>
+        <translation type="obsolete">Usuário Atual:</translation>
     </message>
     <message>
         <source>RDLogin</source>
@@ -56,5 +58,17 @@ Padrão</translation>
         <source>Invalid Username or Password!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current User</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
