@@ -1,10 +1,8 @@
 // edit_clockline.h
 //
-// Edit A Rivendell Log Clock
+// Edit A Rivendell Log Clock Event
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_eventline.h,v 1.7 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,16 +21,13 @@
 #ifndef EDIT_CLOCKLINE_H
 #define EDIT_CLOCKLINE_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qlineedit.h>
-#include <qdatetimeedit.h>
 
-#include <rdevent_line.h>
 #include <rdclock.h>
+#include <rddialog.h>
 #include <rdtimeedit.h>
 
-class EditEventLine : public QDialog
+class EditEventLine : public RDDialog
 {
  Q_OBJECT
  public:
