@@ -2,7 +2,7 @@
 //
 // Calendar widget.
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,18 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qwidget.h>
-#include <qstring.h>
-#include <qlabel.h>
-#include <qpalette.h>
-#include <rddb.h>
-#include <svc_rec.h>
+#include <QMouseEvent>
+
+#include <rdescape_string.h>
+
+#include "svc_rec.h"
 
 //
 // Global Classes
 //
 SvcRec::SvcRec(const QString &svcname,QWidget *parent)
-  :QWidget(parent)
+  : RDWidget(parent)
 {
   QString sql;
   RDSqlQuery *q;
@@ -38,22 +37,18 @@ SvcRec::SvcRec(const QString &svcname,QWidget *parent)
   //
   // Generate Fonts
   //
-  pick_day_font[0]=QFont("Helvetica",12,QFont::Normal);
-  pick_day_font[0].setPixelSize(12);
-  pick_day_font[1]=QFont("Helvetica",12,QFont::Bold);
-  pick_day_font[1].setPixelSize(12);
+  pick_day_font[0]=font();
+  pick_day_font[1]=labelFont();
 
   //
   // Generate Date Boundaries
   //
-  pick_tablename=svcname;
-  pick_tablename.replace(" ","_");
   QDate current_date=QDate::currentDate();
   pick_high_year=current_date.year();
   pick_low_year=pick_high_year;
-  sql=QString().sprintf("select EVENT_DATETIME from `%s_SRT`\
-                         order by EVENT_DATETIME",
-			(const char *)pick_tablename);
+  sql=QString("select EVENT_DATETIME from ELR_LINES where ")+
+    "SERVICE_NAME=\""+RDEscapeString(svcname)+"\" "+
+    "order by EVENT_DATETIME";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     pick_low_year=q->value(0).toDate().year();
@@ -97,44 +92,44 @@ SvcRec::SvcRec(const QString &svcname,QWidget *parent)
   QLabel *label=new QLabel(tr("Mo"),this);
   label->setGeometry(SVC_REC_X_ORIGIN,30,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
 
   label=new QLabel(tr("Tu"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
 
   label=new QLabel(tr("We"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*2,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
 
   label=new QLabel(tr("Th"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*3,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
 
   label=new QLabel(tr("Fr"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*4,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
 
   label=new QLabel(tr("Sa"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*5,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
   label->setPalette(weekend_palette);
 
   label=new QLabel(tr("Su"),this);
   label->setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*6,
 		     SVC_REC_Y_ORIGIN,30,30);
   label->setFont(pick_day_font[1]);
-  label->setAlignment(AlignCenter);
+  label->setAlignment(Qt::AlignCenter);
   label->setPalette(weekend_palette);
 
 
@@ -144,7 +139,7 @@ SvcRec::SvcRec(const QString &svcname,QWidget *parent)
       pick_date_label[i][j]->
 	setGeometry(SVC_REC_X_ORIGIN+SVC_REC_X_INTERVAL*j,
 		    SVC_REC_Y_ORIGIN+20+SVC_REC_Y_INTERVAL*i,30,30);
-      pick_date_label[i][j]->setAlignment(AlignCenter);
+      pick_date_label[i][j]->setAlignment(Qt::AlignCenter);
     }
   }
   PrintDays();
@@ -214,14 +209,10 @@ void SvcRec::deleteDay()
   QString sql;
   RDSqlQuery *q;
 
-  QString tablename=pick_service_name;
-  tablename.replace(" ","_");
-  sql=QString().sprintf("delete from `%s_SRT` where \
-                         (EVENT_DATETIME>=\"%s\")&&\
-                         (EVENT_DATETIME<=\"%s\")",
-			(const char *)tablename,
-			(const char *)date().toString("yyyy-MM-dd 00:00:00"),
-			(const char *)date().toString("yyyy-MM-dd 23:59:59"));
+  sql=QString("delete from ELR_LINES where ")+
+    "SERVICE_NAME=\""+RDEscapeString(pick_service_name)+"\" && "+
+    "EVENT_DATETIME>=\""+date().toString("yyyy-MM-dd 00:00:00")+"\" && "+
+    "EVENT_DATETIME<\""+date().addDays(1).toString("yyyy-MM-dd 00:00:00")+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   GetActiveDays(pick_date);
@@ -403,13 +394,11 @@ void SvcRec::GetActiveDays(const QDate &date)
   QString sql;
   RDSqlQuery *q;
 
-  for(int i=0;i<=31;i++) {
-    sql=QString().sprintf("select ID from `%s_SRT` where \
-                           (EVENT_DATETIME>=\"%s-%02d 00:00:00\")&&\
-                           (EVENT_DATETIME<=\"%s-%02d 23:59:59\")",
-			  (const char *)pick_tablename,
-			  (const char *)date.toString("yyyy-MM"),i+1,
-			  (const char *)date.toString("yyyy-MM"),i+1);
+  for(int i=0;i<=date.daysInMonth();i++) {
+    sql=QString("select ID from ELR_LINES where ")+
+      "SERVICE_NAME=\""+RDEscapeString(pick_service_name)+"\" && "+
+      "(EVENT_DATETIME>=\""+date.toString("yyyy-MM")+QString().sprintf("-%02d 00:00:00\")&&",i+1)+
+      "(EVENT_DATETIME<=\""+date.toString("yyyy-MM")+QString().sprintf("-%02d 23:59:59\")",i+1);
     q=new RDSqlQuery(sql);
     pick_active_days[i]=q->first();
     delete q;
