@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal -- DeleteAudio service
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,15 +19,17 @@
 //
 
 #include <stdio.h>
+#include <syslog.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
 
-#include <rdformpost.h>
-#include <rdweb.h>
+#include <rdapplication.h>
 #include <rdcart.h>
 #include <rdconf.h>
+#include <rdformpost.h>
+#include <rdweb.h>
 
 #include <rdxport.h>
 
@@ -48,7 +50,7 @@ void Xport::DeleteAudio()
   //
   // Process Request
   //
-  if((!xport_user->deleteCarts())&&(!xport_user->adminConfig())) {
+  if((!rda->user()->deleteCarts())&&(!rda->user()->adminConfig())) {
     XmlExit("User not authorized",404,"deleteaudio.cpp",LINE_NUMBER);
   }
   RDCut *cut=new RDCut(cartnum,cutnum);
@@ -62,7 +64,11 @@ void Xport::DeleteAudio()
     "CUT_NAME=\""+RDCut::cutName(cartnum,cutnum)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
-  syslog(LOG_NOTICE,"unlink(%s): %s",(const char *)RDCut::pathName(cartnum,cutnum),strerror(errno));
+  SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		   QVariant(cartnum));
+  rda->syslog(LOG_DEBUG,"unlink(%s): %s",
+	      (const char *)RDCut::pathName(cartnum,cutnum).utf8(),
+	      strerror(errno));
   delete cut;
   XmlExit("OK",200,"deleteaudio.cpp",LINE_NUMBER);
 }
